@@ -1,8 +1,8 @@
 from dataclasses import dataclass
-from typing import TYPE_CHECKING, Any, Dict, Union
+from typing import TYPE_CHECKING, Any, Dict, Union, Optional
 
 if TYPE_CHECKING:
-    from nonebot.adapters import Event, Message, MessageSegment
+    from nonebot.adapters import Bot, Event, Adapter, Message, MessageSegment
 
 
 @dataclass
@@ -15,6 +15,7 @@ class Api(Model):
     name: str
     data: Dict[str, Any]
     result: Any
+    adapter: Optional["Adapter"]
 
 
 @dataclass
@@ -23,3 +24,4 @@ class Send(Model):
     message: Union[str, "Message", "MessageSegment"]
     kwargs: Dict[str, Any]
     result: Any
+    bot: Optional["Bot"]
